@@ -1,5 +1,5 @@
 class fetcher:
-	def __init__(self, filename = '../assets/content.txt'):
+	def __init__(self, filename):
 		self.filename = filename
 
 	def set_file_source(self, filename):
@@ -11,5 +11,5 @@ class fetcher:
 			return file_contents
 
 if __name__ == '__main__':
-	instance = fetcher()
+	instance = fetcher('/home/peretz/dependencies/assets/content.txt')
 	print(instance.get_content())
